@@ -6,10 +6,10 @@
 #' getting all species in a family.
 #'
 #' @export
-#' @param x Vector of taxa names (character) or IDs (character or numeric)
+#' @param sci_id Vector of taxa names (character) or IDs (character or numeric)
 #' to query.
 #' @param db character; database to query. One or more of `itis`,
-#' `ncbi`, or `worms`. Note that each taxonomic data
+#' `ncbi`, `worms`, or `bold`. Note that each taxonomic data
 #' source has their own identifiers, so that if you provide the wrong
 #' `db` value for the identifier you could get a result, but it will
 #' likely be wrong (not what you were expecting). If using ncbi, we recommend
@@ -18,14 +18,20 @@
 #' rows are considered. Note that this parameter is ignored if you pass in a
 #' taxonomic id of any of the acceptable classes: tsn. NCBI has a
 #' method for this function but rows doesn't work.
+#' @param x Deprecated, see `sci_id`
 #' @param ... Further args passed on to [ritis::hierarchy_down()],
-#' [ncbi_children()], or [worrms::wm_children()].
+#' [ncbi_children()], [worrms::wm_children()], [bold_children()]
 #' See those functions for what parameters can be passed on.
 #'
 #' @section ncbi:
 #' note that with `db = "ncbi"`, we set `ambiguous = TRUE`; that is, children
 #' taxa with words like "unclassified", "unknown", "uncultured", "sp." are
 #' NOT removed
+#' 
+#' @section bold:
+#' BEWARE: `db="bold"` scrapes the BOLD website, so may be unstable. That is,
+#' one day it may work, and the next it may fail. Open an issue if you
+#' encounter an error: https://github.com/ropensci/taxize/issues
 #'
 #' @return A named list of data.frames with the children names of every
 #' supplied taxa. You get an NA if there was no match in the database.
@@ -35,15 +41,18 @@
 #' children(161994, db = "itis")
 #' children(8028, db = "ncbi")
 #' ## works with numeric if as character as well
-#' children("161994", db = "itis")
+#' children(161994, db = "itis")
+#' children(88899, db = "bold")
+#' children(as.boldid(88899))
 #'
 #' # Plug in taxon names
 #' children("Salmo", db = 'itis')
 #' children("Salmo", db = 'ncbi')
 #' children("Salmo", db = 'worms')
+#' children("Salmo", db = 'bold')
 #'
 #' # Plug in IDs
-#' (id <- get_wormsid("Platanista"))
+#' (id <- get_wormsid("Gadus"))
 #' children(id)
 #'
 #' # Many taxa
@@ -70,35 +79,43 @@ children <- function(...){
 
 #' @export
 #' @rdname children
-children.default <- function(x, db = NULL, rows = NA, ...) {
+children.default <- function(sci_id, db = NULL, rows = NA, x = NULL, ...) {
   nstop(db)
+  pchk(x, "sci_id")
+  if (!is.null(x)) sci_id <- x
   results <- switch(
     db,
     itis = {
-      id <- process_children_ids(x, db, get_tsn, rows = rows, ...)
-      stats::setNames(children(id, ...), x)
+      id <- process_children_ids(sci_id, db, get_tsn, rows = rows, ...)
+      stats::setNames(children(id, ...), sci_id)
     },
 
     ncbi = {
-      if (all(grepl("^[[:digit:]]*$", x))) {
-        id <- x
+      if (all(grepl("^[[:digit:]]*$", sci_id))) {
+        id <- sci_id
         class(id) <- "uid"
-        stats::setNames(children(id, ...), x)
+        stats::setNames(children(id, ...), sci_id)
       } else {
-        out <- ncbi_children(name = x, ...)
-        structure(out, class = 'children', db = 'ncbi', .Names = x)
+        out <- ncbi_children(name = sci_id, ...)
+        structure(out, class = 'children', db = 'ncbi', .Names = sci_id)
       }
     },
 
     worms = {
-      id <- process_children_ids(x, db, get_wormsid, rows = rows, ...)
-      stats::setNames(children(id, ...), x)
+      id <- process_children_ids(sci_id, db, get_wormsid, rows = rows, ...)
+      stats::setNames(children(id, ...), sci_id)
+    },
+
+    bold = {
+      id <- process_children_ids(as.character(sci_id), db, get_boldid,
+        rows = rows, ...)
+      stats::setNames(children(id, ...), sci_id)
     },
 
     stop("the provided db value was not recognised", call. = FALSE)
   )
 
-  set_output_types(results, x, db)
+  set_output_types(results, sci_id, db)
 }
 
 # Ensure that the output types are consistent when searches return nothing
@@ -110,7 +127,7 @@ itis_blank <- data.frame(
   tsn        = character(0),
   stringsAsFactors = FALSE
 )
-worms_blank <- ncbi_blank <-
+worms_blank <- ncbi_blank <- bold_blank <-
   data.frame(
     childtaxa_id     = character(0),
     childtaxa_name   = character(0),
@@ -123,7 +140,8 @@ set_output_types <- function(x, x_names, db){
     db,
     itis  = function(w) if (nrow(w) == 0 || all(is.na(w))) itis_blank else w,
     ncbi  = function(w) if (nrow(w) == 0 || all(is.na(w))) ncbi_blank else w,
-    worms = function(w) if (nrow(w) == 0 || all(is.na(w))) worms_blank else w
+    worms = function(w) if (nrow(w) == 0 || all(is.na(w))) worms_blank else w,
+    bold = function(w) if (nrow(w) == 0 || all(is.na(w))) bold_blank else w
   )
 
   typed_results <- lapply(seq_along(x), function(i) blank_fun(x[[i]]))
@@ -134,9 +152,9 @@ set_output_types <- function(x, x_names, db){
 
 process_children_ids <- function(input, db, fxn, ...){
   g <- tryCatch(as.numeric(as.character(input)), warning = function(e) e)
-  if (inherits(g, "condition")) eval(fxn)(input, ...)
+  if (inherits(g, "condition")) return(eval(fxn)(input, ...))
   if (is.numeric(g) || is.character(input) && all(grepl("[[:digit:]]", input))) {
-    as_fxn <- switch(db, itis = as.tsn, worms = as.wormsid)
+    as_fxn <- switch(db, itis = as.tsn, worms = as.wormsid, bold = as.boldid)
     as_fxn(input, check = FALSE)
   } else {
     eval(fxn)(input, ...)
@@ -145,7 +163,7 @@ process_children_ids <- function(input, db, fxn, ...){
 
 #' @export
 #' @rdname children
-children.tsn <- function(x, db = NULL, ...) {
+children.tsn <- function(sci_id, db = NULL, ...) {
   warn_db(list(db = db), "itis")
   fun <- function(y){
     # return NA if NA is supplied
@@ -155,8 +173,8 @@ children.tsn <- function(x, db = NULL, ...) {
 		  out <- ritis::hierarchy_down(y, ...)
     }
   }
-  out <- lapply(x, fun)
-  names(out) <- x
+  out <- lapply(sci_id, fun)
+  names(out) <- sci_id
   class(out) <- 'children'
   attr(out, 'db') <- 'itis'
   return(out)
@@ -173,31 +191,22 @@ df2dt2tbl <- function(x) {
 
 #' @export
 #' @rdname children
-children.wormsid <- function(x, db = NULL, ...) {
+children.wormsid <- function(sci_id, db = NULL, ...) {
   warn_db(list(db = db), "worms")
   fun <- function(y){
     # return NA if NA is supplied
     if (is.na(y)) {
       out <- NA
     } else {
-      out <- worrms::wm_children(as.numeric(y))
-      out <- list(out)
-      i <- 1
-      while (NROW(out[[length(out)]]) == 50) {
-        i <- i + 1
-        out[[i]] <- worrms::wm_children(
-          as.numeric(y),
-          offset = sum(unlist(sapply(out, NROW))))
-      }
-      out <- df2dt2tbl(out)
+      out <- worms_children_all(y, ...)
       stats::setNames(
         out[names(out) %in% c('AphiaID', 'scientificname', 'rank')],
         c('childtaxa_id', 'childtaxa_name', 'childtaxa_rank')
       )
     }
   }
-  out <- lapply(x, fun)
-  names(out) <- x
+  out <- lapply(sci_id, fun)
+  names(out) <- sci_id
   class(out) <- 'children'
   attr(out, 'db') <- 'worms'
   return(out)
@@ -205,7 +214,7 @@ children.wormsid <- function(x, db = NULL, ...) {
 
 #' @export
 #' @rdname children
-children.ids <- function(x, db = NULL, ...) {
+children.ids <- function(sci_id, db = NULL, ...) {
   fun <- function(y, ...){
     # return NA if NA is supplied
     if (is.na(y)) {
@@ -215,21 +224,35 @@ children.ids <- function(x, db = NULL, ...) {
     }
     return(out)
   }
-  out <- lapply(x, fun)
+  out <- lapply(sci_id, fun)
   class(out) <- 'children_ids'
   return(out)
 }
 
 #' @export
 #' @rdname children
-children.uid <- function(x, db = NULL, ...) {
+children.uid <- function(sci_id, db = NULL, ...) {
   warn_db(list(db = db), "uid")
-  out <- if (is.na(x)) {
-    stats::setNames(list(ncbi_blank), x)
+  out <- if (is.na(sci_id)) {
+    stats::setNames(list(ncbi_blank), sci_id)
   } else {
-    ncbi_children(id = x, ambiguous = TRUE, ...)
+    ncbi_children(id = sci_id, ambiguous = TRUE, ...)
   }
   class(out) <- 'children'
   attr(out, 'db') <- 'ncbi'
   return(out)
 }
+
+#' @export
+#' @rdname children
+children.boldid <- function(sci_id, db = NULL, ...) {
+  warn_db(list(db = db), "bold")
+  out <- if (is.na(sci_id)) {
+    stats::setNames(list(bold_blank), sci_id)
+  } else {
+    bold_children(id = sci_id, ...)
+  }
+  class(out) <- 'children'
+  attr(out, 'db') <- 'bold'
+  return(out)
+}
