@@ -2,9 +2,9 @@
 #'
 #' @export
 #' @param id the taxon identifier code
-#' @param key Your Tropicos API key; See \code{\link{taxize-authentication}} 
+#' @param key Your Tropicos API key; See [taxize-authentication] 
 #' for help on authentication
-#' @param ... Curl options passed on to \code{\link[crul]{HttpClient}}
+#' @param ... Curl options passed on to [crul::HttpClient]
 #' @return List or dataframe.
 #' @examples \dontrun{
 #' tp_synonyms(id = 25509881)
@@ -25,7 +25,7 @@ tp_synonyms <- function(id, key = NULL, ...) {
   } else {
     dat <- lapply(res, function(x) lapply(x, data.frame, stringsAsFactors = FALSE))
     accepted <- dat[[1]]$AcceptedName
-    df <- do.call(rbind.fill, lapply(dat, "[[", "SynonymName"))
+    df <- dt2df(lapply(dat, "[[", "SynonymName"), idcol = FALSE)
     synonyms <- df[!duplicated.data.frame(df), ]
     names(accepted) <- tolower(names(accepted))
     names(synonyms) <- tolower(names(synonyms))
