@@ -7,7 +7,7 @@
 #' the function.
 #'
 #' @export
-#' @param x Vector of taxa names (character) or IDs (character or numeric) to
+#' @param sci_id Vector of taxa names (character) or IDs (character or numeric) to
 #' query.
 #' @param db character; database to query. One or both of `itis`. Note
 #' that each taxonomic data source has their own identifiers, so that if you
@@ -23,13 +23,14 @@
 #' @param rows (numeric) Any number from 1 to infinity. If the default NA, all
 #' rows are considered. Note that this parameter is ignored if you pass in a
 #' taxonomic id of any of the acceptable classes: tsn.
+#' @param x Deprecated, see `sci_id`
 #' @param ... Further args passed on to [itis_downstream()]
 #'
 #' @return A named list of data.frames with the upstream names of every
 #' supplied taxa. You get an NA if there was no match in the database.
 #'
 #' @examples \dontrun{
-#' upstream(x='Pinus contorta', db = 'itis', upto = 'genus')
+#' upstream('Pinus contorta', db = 'itis', upto = 'genus')
 #' }
 upstream <- function(...) {
   UseMethod("upstream")
@@ -37,14 +38,18 @@ upstream <- function(...) {
 
 #' @export
 #' @rdname upstream
-upstream.default <- function(x, db = NULL, upto = NULL, rows = NA, ...){
+upstream.default <- function(sci_id, db = NULL, upto = NULL, rows = NA,
+  x = NULL, ...) {
+
   nstop(upto, "upto")
   nstop(db)
+  pchk(x, "sci_id")
+  if (!is.null(x)) sci_id <- x
   switch(
     db,
     itis = {
-      id <- process_stream_ids(x, db, get_tsn, rows = rows, ...)
-      setNames(upstream(id, upto = tolower(upto), ...), x)
+      id <- process_stream_ids(sci_id, db, get_tsn, rows = rows, ...)
+      setNames(upstream(id, upto = tolower(upto), ...), sci_id)
     },
     stop("the provided db value was not recognised", call. = FALSE)
   )
@@ -52,7 +57,7 @@ upstream.default <- function(x, db = NULL, upto = NULL, rows = NA, ...){
 
 #' @export
 #' @rdname upstream
-upstream.tsn <- function(x, db = NULL, upto = NULL, ...) {
+upstream.tsn <- function(sci_id, db = NULL, upto = NULL, ...) {
   warn_db(list(db = db), "itis")
   fun <- function(y, ...){
     # return NA if NA is supplied
@@ -61,16 +66,16 @@ upstream.tsn <- function(x, db = NULL, upto = NULL, ...) {
     } else {
       class <- classification(y, ...)
       toget <- class[[1]][ grep(upto, class[[1]]$rank) - 1, c("name", "id") ]
-      setNames(downstream(x = as.tsn(toget$id), downto = upto, ...), toget$name)
+      setNames(downstream(as.tsn(toget$id), downto = upto, ...), toget$name)
     }
   }
-  out <- if (length(x) > 1) lapply(x, fun, ...) else fun(x, ...)
+  out <- if (length(sci_id) > 1) lapply(sci_id, fun, ...) else fun(sci_id, ...)
   structure(out, class = 'upstream', db = 'itis')
 }
 
 #' @export
 #' @rdname upstream
-upstream.ids <- function(x, db = NULL, upto = NULL, ...) {
+upstream.ids <- function(sci_id, db = NULL, upto = NULL, ...) {
   fun <- function(y, ...){
     # return NA if NA is supplied
     if (is.na(y)) {
@@ -80,5 +85,6 @@ upstream.ids <- function(x, db = NULL, upto = NULL, ...) {
     }
     return(out)
   }
-  structure(if (length(x) > 1) lapply(x, fun, ...) else fun(x, ...), class = 'downstream_ids')
+  out <- if (length(sci_id) > 1) lapply(sci_id, fun, ...) else fun(sci_id, ...)
+  structure(out, class = 'downstream_ids')
 }
