@@ -1,9 +1,10 @@
 context("get_tsn")
 
 test_that("get_tsn returns the correct value", {
+  skip_on_cran()
   vcr::use_cassette("get_tsn", {
-    x <- get_tsn("asdfasdf", verbose=FALSE)[[1]]
-    z <- get_tsn("Chironomus riparius", verbose=FALSE)
+    x <- get_tsn("asdfasdf", messages=FALSE)[[1]]
+    z <- get_tsn("Chironomus riparius", messages=FALSE)
   })
 
 	expect_true(is.na(x))
@@ -11,37 +12,38 @@ test_that("get_tsn returns the correct value", {
 })
 
 test_that("get_tsn accepts ask and verbose arguments", {
+  skip_on_cran()
   vcr::use_cassette("get_tsn_ask_verbose_args", {
     expect_message(sw(get_tsn('Dugesia', messages=TRUE, ask = FALSE)))
     expect_true(all(is.na(sw(get_tsn('black bear', searchtype="common",
-      ask=FALSE, verbose=FALSE)))))
+      ask=FALSE, messages=FALSE)))))
   })
 })
 
 test_that("get_tsn fails as expected", {
   skip_on_cran()
 
-  expect_error(get_tsn(), "argument \"searchterm\" is missing")
-  expect_error(get_tsn("Arni", ask = 4, verbose = FALSE),
+  expect_error(get_tsn(), "argument \"sci_com\" is missing")
+  expect_error(get_tsn("Arni", ask = 4, messages = FALSE),
                "ask must be of class logical")
   expect_error(
-    get_tsn(searchterm="black bear", searchtype=5,
-            verbose = FALSE),
+    get_tsn(sci_com="black bear", searchtype=5,
+            messages = FALSE),
     "searchtype must be of class character")
   expect_error(
     get_tsn("Arni", accepted = 34,
-            verbose = FALSE),
+            messages = FALSE),
     "accepted must be of class logical")
 
   # searchtype values
   expect_error(
-    get_tsn(searchterm="black bear", searchtype="asdfadf",
-            verbose = FALSE),
+    get_tsn(sci_com="black bear", searchtype="asdfadf",
+            messages = FALSE),
     "'arg' should be one of")
 
   # rows param
-  expect_error(get_tsn("Achlya", rows = "foobar", verbose = FALSE),
+  expect_error(get_tsn("Achlya", rows = "foobar", messages = FALSE),
                "rows must be of class numeric, integer")
-  expect_error(get_tsn("Achlya", rows = 0, verbose = FALSE),
-               "rows > 0 is not TRUE")
+  expect_error(get_tsn("Achlya", rows = 0, messages = FALSE),
+               "all\\(rows > 0\\) is not TRUE")
 })
